@@ -28,15 +28,16 @@
 #ifndef ROFI_DIALOG_DRUN_H
 #define ROFI_DIALOG_DRUN_H
 
+#include "mode.h"
+
 /**
  * @defgroup DRUNMode DRun
  * @ingroup MODES
  * @{
  */
-#include <config.h>
 #ifdef ENABLE_DRUN
 /** #Mode object representing the desktop menu run dialog. */
 extern Mode drun_mode;
 #endif // ENABLE_DRUN
-/*@}*/
+/**@}*/
 #endif // ROFI_DIALOG_DRUN_H
