@@ -27,14 +27,14 @@
 
 #ifndef ROFI_DIALOG_SSH_H
 #define ROFI_DIALOG_SSH_H
-
+#include "mode.h"
 /**
  * @defgroup SSHMode SSH
  * @ingroup MODES
  *
  * SSH Mode, returns a list of known SSH hosts the user can log into.
- * It does this by parsing the SSH config file and optional the known host  and host list
- * It also keeps history of the last chosen hosts.
+ * It does this by parsing the SSH config file and optional the known host  and
+ * host list It also keeps history of the last chosen hosts.
  *
  * This mode uses the following options from the #config object:
  *  * #Settings::ssh_command
@@ -46,5 +46,5 @@
 
 /** #Mode object representing the ssh dialog. */
 extern Mode ssh_mode;
-/*@}*/
+/**@}*/
 #endif // ROFI_DIALOG_SSH_H
