@@ -28,17 +28,20 @@
 #ifndef ROFI_DIALOG_WINDOW_H
 #define ROFI_DIALOG_WINDOW_H
 
+#include "mode.h"
+
 /**
  * @defgroup WINDOWMode Window
  * @ingroup MODES
  *
  * @{
  */
-#include <config.h>
 #ifdef WINDOW_MODE
 
 extern Mode window_mode;
 extern Mode window_mode_cd;
+
+void window_client_handle_signal(xcb_window_t win, gboolean create);
 #endif // WINDOW_MODE
-/* @}*/
+/** @}*/
 #endif // ROFI_DIALOG_WINDOW_H
