@@ -149,10 +149,11 @@ int execute_generator(const char *cmd) __attribute__((nonnull));
 
 /**
  * @param pidfile The pidfile to create.
+ * @param kill Try killing running instance.
  *
  * returns file descriptor (or -1 when failed)
  */
-int create_pid_file(const char *pidfile);
+int create_pid_file(const char *pidfile, gboolean kill);
 
 /**
  * Remove pid file
@@ -228,15 +229,6 @@ char *rofi_force_utf8(const gchar *data, ssize_t length);
  */
 char *rofi_latin_to_utf8_strdup(const char *input, gssize length);
 
-/**
- * @param text the string to escape
- *
- * Escape XML markup from the string. text is freed.
- *
- * @return the escaped string
- */
-gchar *rofi_escape_markup(gchar *text);
-
 /**
  * @param pattern   The user input to match against.
  * @param plen      Pattern length.
