@@ -176,7 +176,9 @@ static void listview_add_widget(listview *lv, _listview_row *row, widget *wid,
   } else {
     widget *wid2 = (widget *)box_create(wid, label, ROFI_ORIENTATION_VERTICAL);
     box_add((box *)wid, WIDGET(wid2), TRUE);
-    GList *list = rofi_theme_get_list(WIDGET(wid2), "children", "");
+    GList *list = rofi_theme_get_list_strings(
+        WIDGET(wid2),
+        "children"); // rofi_theme_get_list(WIDGET(wid2), "children", "");
     for (GList *iter = g_list_first(list); iter != NULL;
          iter = g_list_next(iter)) {
       listview_add_widget(lv, row, wid2, (const char *)iter->data);
@@ -188,11 +190,14 @@ static void listview_create_row(listview *lv, _listview_row *row) {
   row->box = box_create(WIDGET(lv), "element", ROFI_ORIENTATION_HORIZONTAL);
   widget_set_type(WIDGET(row->box), WIDGET_TYPE_LISTVIEW_ELEMENT);
   GList *list = NULL;
-  if (config.show_icons) {
-    list = rofi_theme_get_list(WIDGET(row->box), "children",
-                               "element-icon,element-text");
-  } else {
-    list = rofi_theme_get_list(WIDGET(row->box), "children", "element-text");
+  list = rofi_theme_get_list_strings(WIDGET(row->box), "children");
+  if (list == NULL) {
+    if (config.show_icons) {
+      list = g_list_append(list, g_strdup("element-icon"));
+      list = g_list_append(list, g_strdup("element-text"));
+    } else {
+      list = g_list_append(list, g_strdup("element-text"));
+    }
   }
 
   row->textbox = NULL;
@@ -946,12 +951,6 @@ void listview_set_num_lines(listview *lv, unsigned int num_lines) {
   }
 }
 
-unsigned int listview_get_num_lines(listview *lv) {
-  if (lv) {
-    return lv->menu_lines;
-  }
-  return 0;
-}
 void listview_set_max_lines(listview *lv, unsigned int max_lines) {
   if (lv) {
     lv->max_displayed_lines = max_lines;
