@@ -46,18 +46,15 @@
 ThemeWidget *rofi_configuration = NULL;
 
 /** Different sources of configuration. */
-const char *const ConfigSourceStr[] = {
-    "Default",
-    "File",
-    "Rasi File",
-    "Commandline",
-};
+const char *const ConfigSourceStr[] = {"Default", "File", "Rasi File",
+                                       "Commandline", "Don't Display"};
 /** Enumerator of different sources of configuration. */
 enum ConfigSource {
   CONFIG_DEFAULT = 0,
   CONFIG_FILE = 1,
   CONFIG_FILE_THEME = 2,
-  CONFIG_CMDLINE = 3
+  CONFIG_CMDLINE = 3,
+  CONFIG_NO_DISPLAY = 4
 };
 
 typedef struct {
@@ -346,7 +343,7 @@ static XrmOption xrmOptions[] = {
      {.str = &config.theme},
      NULL,
      "New style theme file",
-     CONFIG_DEFAULT},
+     CONFIG_DEFAULT | CONFIG_NO_DISPLAY},
     {xrm_Number,
      "max-history-size",
      {.num = &config.max_history_size},
@@ -357,7 +354,14 @@ static XrmOption xrmOptions[] = {
      "combi-hide-mode-prefix",
      {.snum = &config.combi_hide_mode_prefix},
      NULL,
-     "Hide the prefix mode prefix on the combi view.",
+     "Hide the prefix mode prefix on the combi view.**deprecated** use "
+     "combi-display-format",
+     CONFIG_DEFAULT},
+    {xrm_String,
+     "combi-display-format",
+     {.str = &config.combi_display_format},
+     NULL,
+     "Combi format string. (Supports: mode, text)",
      CONFIG_DEFAULT},
     {xrm_Char,
      "matching-negate-char",
@@ -466,12 +470,12 @@ static void config_parse_cmd_option(XrmOption *option) {
   switch (option->type) {
   case xrm_Number:
     if (find_arg_uint(key, option->value.num) == TRUE) {
-      option->source = CONFIG_CMDLINE;
+      option->source = (option->source & ~3) | CONFIG_CMDLINE;
     }
     break;
   case xrm_SNumber:
     if (find_arg_int(key, option->value.snum) == TRUE) {
-      option->source = CONFIG_CMDLINE;
+      option->source = (option->source & ~3) | CONFIG_CMDLINE;
     }
     break;
   case xrm_String:
@@ -480,25 +484,25 @@ static void config_parse_cmd_option(XrmOption *option) {
         g_free(option->mem);
         option->mem = NULL;
       }
-      option->source = CONFIG_CMDLINE;
+      option->source = (option->source & ~3) | CONFIG_CMDLINE;
     }
     break;
   case xrm_Boolean:
     if (find_arg(key) >= 0) {
       *(option->value.num) = TRUE;
-      option->source = CONFIG_CMDLINE;
+      option->source = (option->source & ~3) | CONFIG_CMDLINE;
     } else {
       g_free(key);
       key = g_strdup_printf("-no-%s", option->name);
       if (find_arg(key) >= 0) {
         *(option->value.num) = FALSE;
-        option->source = CONFIG_CMDLINE;
+        option->source = (option->source & ~3) | CONFIG_CMDLINE;
       }
     }
     break;
   case xrm_Char:
     if (find_arg_char(key, option->value.charc) == TRUE) {
-      option->source = CONFIG_CMDLINE;
+      option->source = (option->source & ~3) | CONFIG_CMDLINE;
     }
     break;
   default:
@@ -507,6 +511,25 @@ static void config_parse_cmd_option(XrmOption *option) {
   g_free(key);
 }
 
+static gboolean config_parser_form_rasi_format(GString *str, char **tokens,
+                                               int count, char *argv,
+                                               gboolean string) {
+  for (int j = 0; j < (count - 1); j++) {
+    g_string_append_printf(str, "%s { ", tokens[j]);
+  }
+  if (string) {
+    char *esc = g_strescape(argv, NULL);
+    g_string_append_printf(str, "%s: \"%s\";", tokens[count - 1], esc);
+    g_free(esc);
+  } else {
+    g_string_append_printf(str, "%s: %s;", tokens[count - 1], argv);
+  }
+  for (int j = 0; j < (count - 1); j++) {
+    g_string_append(str, " } ");
+  }
+  return TRUE;
+}
+
 void config_parse_cmd_options(void) {
   for (unsigned int i = 0; i < sizeof(xrmOptions) / sizeof(XrmOption); ++i) {
     XrmOption *op = &(xrmOptions[i]);
@@ -523,41 +546,53 @@ void config_parse_cmd_options(void) {
   extern char **stored_argv;
   for (int in = 1; in < (stored_argc - 1); in++) {
     if (stored_argv[in][0] == '-') {
+      if (stored_argv[in + 1][0] == '-') {
+        continue;
+      }
       /** TODO: This is a hack, and should be fixed in a nicer way. */
       char **tokens = g_strsplit(stored_argv[in], "-", 3);
       int count = 1;
       for (int j = 1; tokens && tokens[j]; j++) {
         count++;
       }
-      if (count > 2 && g_strcmp0(tokens[1], "no") != 0) {
-        GString *str = g_string_new("configuration { ");
-        for (int j = 1; j < (count - 1); j++) {
-          g_string_append_printf(str, "%s { ", tokens[j]);
-        }
-        g_string_append_printf(str, "%s: %s;", tokens[count - 1],
-                               stored_argv[in + 1]);
-        for (int j = 0; j < (count - 1); j++) {
-          g_string_append(str, " } ");
-        }
-        if (rofi_theme_parse_string(str->str) == 1) {
-          /** Failed to parse, try again as string. */
-          rofi_clear_error_messages();
-          g_string_assign(str, "configuration { ");
-          for (int j = 1; j < (count - 1); j++) {
-            g_string_append_printf(str, "%s { ", tokens[j]);
-          }
-          char *esc = g_strescape(stored_argv[in + 1], NULL);
-          g_string_append_printf(str, "%s: \"%s\";", tokens[count - 1], esc);
-          g_free(esc);
-          for (int j = 0; j < (count - 1); j++) {
-            g_string_append(str, " } ");
+      if (count >= 2) {
+        if (g_str_has_prefix(tokens[1], "theme")) {
+          g_strfreev(tokens);
+          tokens = g_strsplit(stored_argv[in], "+", 0);
+          count = g_strv_length(tokens);
+          if (count > 2) {
+            GString *str = g_string_new("");
+            config_parser_form_rasi_format(str, &(tokens[1]), count - 1,
+                                           stored_argv[in + 1], FALSE);
+            if (rofi_theme_parse_string(str->str) == 1) {
+              /** Failed to parse, try again as string. */
+              g_strfreev(tokens);
+              g_string_free(str, TRUE);
+              return;
+            }
+            g_string_free(str, TRUE);
           }
+        } else if (g_strcmp0(tokens[1], "no") != 0) {
+          GString *str = g_string_new("configuration { ");
+          config_parser_form_rasi_format(str, &(tokens[1]), count - 1,
+                                         stored_argv[in + 1], FALSE);
+          g_string_append(str, "}");
+          g_debug("str: \"%s\"\n", str->str);
           if (rofi_theme_parse_string(str->str) == 1) {
             /** Failed to parse, try again as string. */
             rofi_clear_error_messages();
+            g_string_assign(str, "configuration { ");
+            config_parser_form_rasi_format(str, &(tokens[1]), count - 1,
+                                           stored_argv[in + 1], TRUE);
+            g_string_append(str, "}");
+            g_debug("str: \"%s\"\n", str->str);
+            if (rofi_theme_parse_string(str->str) == 1) {
+              /** Failed to parse, try again as string. */
+              rofi_clear_error_messages();
+            }
           }
+          g_string_free(str, TRUE);
         }
-        g_string_free(str, TRUE);
         in++;
       }
       g_strfreev(tokens);
@@ -578,10 +613,11 @@ static gboolean __config_parser_set_property(XrmOption *option,
     if (p->type == P_LIST) {
       for (GList *iter = p->value.list; iter != NULL;
            iter = g_list_next(iter)) {
+        Property *p = (Property *)iter->data;
         if (value == NULL) {
-          value = g_strdup((char *)(iter->data));
+          value = g_strdup((char *)(p->value.s));
         } else {
-          char *nv = g_strjoin(",", value, (char *)(iter->data), NULL);
+          char *nv = g_strjoin(",", value, (char *)(p->value.s), NULL);
           g_free(value);
           value = nv;
         }
@@ -597,7 +633,7 @@ static gboolean __config_parser_set_property(XrmOption *option,
 
     // Memory
     (option)->mem = *(option->value.str);
-    option->source = CONFIG_FILE_THEME;
+    option->source = (option->source & ~3) | CONFIG_FILE_THEME;
   } else if (option->type == xrm_Number) {
     if (p->type != P_INTEGER) {
       *error =
@@ -606,7 +642,7 @@ static gboolean __config_parser_set_property(XrmOption *option,
       return TRUE;
     }
     *(option->value.snum) = p->value.i;
-    option->source = CONFIG_FILE_THEME;
+    option->source = (option->source & ~3) | CONFIG_FILE_THEME;
   } else if (option->type == xrm_SNumber) {
     if (p->type != P_INTEGER) {
       *error =
@@ -615,7 +651,7 @@ static gboolean __config_parser_set_property(XrmOption *option,
       return TRUE;
     }
     *(option->value.num) = (unsigned int)(p->value.i);
-    option->source = CONFIG_FILE_THEME;
+    option->source = (option->source & ~3) | CONFIG_FILE_THEME;
   } else if (option->type == xrm_Boolean) {
     if (p->type != P_BOOLEAN) {
       *error =
@@ -624,7 +660,7 @@ static gboolean __config_parser_set_property(XrmOption *option,
       return TRUE;
     }
     *(option->value.num) = (p->value.b);
-    option->source = CONFIG_FILE_THEME;
+    option->source = (option->source & ~3) | CONFIG_FILE_THEME;
   } else if (option->type == xrm_Char) {
     if (p->type != P_CHAR) {
       *error = g_strdup_printf(
@@ -633,7 +669,7 @@ static gboolean __config_parser_set_property(XrmOption *option,
       return TRUE;
     }
     *(option->value.charc) = (p->value.c);
-    option->source = CONFIG_FILE_THEME;
+    option->source = (option->source & ~3) | CONFIG_FILE_THEME;
   } else {
     // TODO add type
     *error = g_strdup_printf("Option: %s is not of a supported type: %s.",
@@ -673,8 +709,7 @@ gboolean config_parse_set_property(const Property *p, char **error) {
     }
   }
   //*error = g_strdup_printf("Option: %s is not found.", p->name);
-  g_warning("Option: %s is not found.", p->name);
-
+  g_debug("Option: %s is not found.", p->name);
 
   for (GList *iter = g_list_first(extra_parsed_options); iter != NULL;
        iter = g_list_next(iter)) {
@@ -713,7 +748,7 @@ void config_xresource_free(void) {
 }
 
 static void config_parse_dump_config_option(FILE *out, XrmOption *option) {
-  if (option->type == xrm_Char || option->source == CONFIG_DEFAULT) {
+  if (option->type == xrm_Char || (option->source & 3) == CONFIG_DEFAULT) {
     fprintf(out, "/*");
   }
   fprintf(out, "\t%s: ", option->name);
@@ -747,7 +782,7 @@ static void config_parse_dump_config_option(FILE *out, XrmOption *option) {
   }
 
   fprintf(out, ";");
-  if (option->type == xrm_Char || option->source == CONFIG_DEFAULT) {
+  if (option->type == xrm_Char || (option->source & 3) == CONFIG_DEFAULT) {
     fprintf(out, "*/");
   }
   fprintf(out, "\n");
@@ -764,12 +799,19 @@ void config_parse_dump_config_rasi_format(FILE *out, gboolean changes) {
         continue;
       }
     }
-    if (!changes || xrmOptions[i].source != CONFIG_DEFAULT) {
+    if ((xrmOptions[i].source & CONFIG_NO_DISPLAY) == CONFIG_NO_DISPLAY) {
+      continue;
+    }
+    if (!changes || (xrmOptions[i].source & 3) != CONFIG_DEFAULT) {
       config_parse_dump_config_option(out, &(xrmOptions[i]));
     }
   }
   for (unsigned int i = 0; i < num_extra_options; i++) {
-    if (!changes || extra_options[i].source != CONFIG_DEFAULT) {
+    if ((extra_options[i].source & CONFIG_NO_DISPLAY) == CONFIG_NO_DISPLAY) {
+      continue;
+    }
+    if (!changes || (extra_options[i].source & 3) != CONFIG_DEFAULT) {
+
       config_parse_dump_config_option(out, &(extra_options[i]));
     }
   }
@@ -780,6 +822,10 @@ void config_parse_dump_config_rasi_format(FILE *out, gboolean changes) {
   }
 
   fprintf(out, "}\n");
+
+  if (config.theme != NULL) {
+    fprintf(out, "@theme \"%s\"\r\n", config.theme);
+  }
 }
 
 static void print_option_string(XrmOption *xo, int is_term) {
@@ -790,12 +836,12 @@ static void print_option_string(XrmOption *xo, int is_term) {
     printf("\t" color_italic "%s" color_reset,
            (*(xo->value.str) == NULL) ? "(unset)" : (*(xo->value.str)));
     printf(" " color_green "(%s)" color_reset "\n",
-           ConfigSourceStr[xo->source]);
+           ConfigSourceStr[xo->source & 3]);
   } else {
     printf("\t-%s [string]%-*c%s\n", xo->name, 30 - l, ' ', xo->comment);
     printf("\t\t%s",
            (*(xo->value.str) == NULL) ? "(unset)" : (*(xo->value.str)));
-    printf(" (%s)\n", ConfigSourceStr[xo->source]);
+    printf(" (%s)\n", ConfigSourceStr[xo->source & 3]);
   }
 }
 static void print_option_number(XrmOption *xo, int is_term) {
@@ -805,11 +851,11 @@ static void print_option_number(XrmOption *xo, int is_term) {
            30 - l, ' ', xo->comment);
     printf("\t" color_italic "%u" color_reset, *(xo->value.num));
     printf(" " color_green "(%s)" color_reset "\n",
-           ConfigSourceStr[xo->source]);
+           ConfigSourceStr[xo->source & 3]);
   } else {
     printf("\t-%s [number]%-*c%s\n", xo->name, 30 - l, ' ', xo->comment);
     printf("\t\t%u", *(xo->value.num));
-    printf(" (%s)\n", ConfigSourceStr[xo->source]);
+    printf(" (%s)\n", ConfigSourceStr[xo->source & 3]);
   }
 }
 static void print_option_snumber(XrmOption *xo, int is_term) {
@@ -819,11 +865,11 @@ static void print_option_snumber(XrmOption *xo, int is_term) {
            30 - l, ' ', xo->comment);
     printf("\t" color_italic "%d" color_reset, *(xo->value.snum));
     printf(" " color_green "(%s)" color_reset "\n",
-           ConfigSourceStr[xo->source]);
+           ConfigSourceStr[xo->source & 3]);
   } else {
     printf("\t-%s [number]%-*c%s\n", xo->name, 30 - l, ' ', xo->comment);
     printf("\t\t%d", *(xo->value.snum));
-    printf(" (%s)\n", ConfigSourceStr[xo->source]);
+    printf(" (%s)\n", ConfigSourceStr[xo->source & 3]);
   }
 }
 static void print_option_char(XrmOption *xo, int is_term) {
@@ -833,11 +879,11 @@ static void print_option_char(XrmOption *xo, int is_term) {
            30 - l, ' ', xo->comment);
     printf("\t" color_italic "%c" color_reset, *(xo->value.charc));
     printf(" " color_green "(%s)" color_reset "\n",
-           ConfigSourceStr[xo->source]);
+           ConfigSourceStr[xo->source & 3]);
   } else {
     printf("\t-%s [character]%-*c%s\n", xo->name, 30 - l, ' ', xo->comment);
     printf("\t\t%c", *(xo->value.charc));
-    printf(" (%s)\n", ConfigSourceStr[xo->source]);
+    printf(" (%s)\n", ConfigSourceStr[xo->source & 3]);
   }
 }
 static void print_option_boolean(XrmOption *xo, int is_term) {
@@ -848,15 +894,18 @@ static void print_option_boolean(XrmOption *xo, int is_term) {
     printf("\t" color_italic "%s" color_reset,
            (*(xo->value.snum)) ? "True" : "False");
     printf(" " color_green "(%s)" color_reset "\n",
-           ConfigSourceStr[xo->source]);
+           ConfigSourceStr[xo->source & 3]);
   } else {
     printf("\t-[no-]%s %-*c%s\n", xo->name, 33 - l, ' ', xo->comment);
     printf("\t\t%s", (*(xo->value.snum)) ? "True" : "False");
-    printf(" (%s)\n", ConfigSourceStr[xo->source]);
+    printf(" (%s)\n", ConfigSourceStr[xo->source & 3]);
   }
 }
 
 static void print_option(XrmOption *xo, int is_term) {
+  if ((xo->source & CONFIG_NO_DISPLAY) == CONFIG_NO_DISPLAY) {
+    return;
+  }
   switch (xo->type) {
   case xrm_String:
     print_option_string(xo, is_term);
