@@ -39,6 +39,7 @@
 #include "rofi.h"
 #include "xrmoptions.h"
 #include "helper.h"
+#include "rofi-icon-fetcher.h"
 unsigned int test =0;
 #define TASSERT( a )    {                                 \
         assert ( a );                                     \
@@ -48,7 +49,7 @@ unsigned int test =0;
 #define TASSERTE( a, b )    {                                                            \
         if ( ( a ) == ( b ) ) {                                                          \
             printf ( "Test %u passed (%s == %s) (%d == %d)\n", ++test, # a, # b, a, b ); \
-        }else {                                                                          \
+        } else {                                                                         \
             printf ( "Test %u failed (%s == %s) (%d != %d)\n", ++test, # a, # b, a, b ); \
             abort ( );                                                                   \
         }                                                                                \
@@ -57,12 +58,26 @@ unsigned int test =0;
 #define TASSERTW( a, b )    {                                                                            \
         if ( ( a ) == ( b ) ) {                                                                          \
             printf ( "Test %u passed (%s == %s) (%p == %p)\n", ++test, # a, # b, (void *)a, (void *)b ); \
-        }else {                                                                                          \
+        } else {                                                                                         \
             printf ( "Test %u failed (%s == %s) (%p != %p)\n", ++test, # a, # b, (void *)a, (void *)b ); \
             abort ( );                                                                                   \
         }                                                                                                \
 }
+ThemeWidget *rofi_configuration = NULL;
 
+uint32_t rofi_icon_fetcher_query ( const char *name, const int size )
+{
+  return 0;
+}
+uint32_t rofi_icon_fetcher_query_advanced ( const char *name, const int wsize, const int hsize )
+{
+  return 0;
+}
+
+cairo_surface_t * rofi_icon_fetcher_get ( const uint32_t uid )
+{
+  return NULL;
+}
 
 int monitor_active ( G_GNUC_UNUSED workarea *mon )
 {
@@ -78,7 +93,7 @@ char * rofi_expand_path ( G_GNUC_UNUSED const char *path )
     return NULL;
 }
 
-char * helper_get_theme_path ( const char *file )
+char * helper_get_theme_path ( const char *file, const char *ext)
 {
     return g_strdup ( file );
 }
@@ -100,7 +115,6 @@ void rofi_view_get_current_monitor ( G_GNUC_UNUSED int *width, G_GNUC_UNUSED int
 
 }
 
-
 int main ( G_GNUC_UNUSED int argc, G_GNUC_UNUSED char **argv )
 {
     {
